@@ -272,7 +272,10 @@ class GenvexNabto():
             return
         Payload = GenvexPayloadCrypt()
         Payload.setData(GenvexCommandDatapointReadList.buildCommand(datalist))
-        self._socket.sendto(GenvexPacket().build_packet(self._client_id, self._server_id, GenvexPacketType.DATA, sequenceId, [Payload]), (self._device_ip, self._device_port))
+        try:
+            self._socket.sendto(GenvexPacket().build_packet(self._client_id, self._server_id, GenvexPacketType.DATA, sequenceId, [Payload]), (self._device_ip, self._device_port))
+        except Exception as e:
+            _LOGGER.error(f'Error sending data state request: {e}')
 
     def sendSetpointStateRequest(self, sequenceId):
         Payload = GenvexPayloadCrypt()
@@ -280,22 +283,30 @@ class GenvexNabto():
         if datalist is False:
             return
         Payload.setData(GenvexCommandSetpointReadList.buildCommand(datalist))
-        self._socket.sendto(GenvexPacket().build_packet(self._client_id, self._server_id, GenvexPacketType.DATA, sequenceId, [Payload]), (self._device_ip, self._device_port))
-
+        try:
+            self._socket.sendto(GenvexPacket().build_packet(self._client_id, self._server_id, GenvexPacketType.DATA, sequenceId, [Payload]), (self._device_ip, self._device_port))
+        except Exception as e:
+            _LOGGER.error(f'Error sending setpoint state request: {e}')
+            
     def setSetpoint(self, setpointKey: GenvexNabtoSetpointKey, newValue) -> bool:
         if self._model_adapter is None:
             return False
         if self._model_adapter.providesValue(setpointKey) is False:
             return False
         setpointData = self._model_adapter._loadedModel._setpoints[setpointKey]
-        newValue = int((newValue * setpointData["divider"]) - setpointData['offset'])
-        if newValue < setpointData['min'] or newValue > setpointData['max']:
+        payloadValue = int((newValue * setpointData["divider"]) - setpointData['offset'])
+        if payloadValue < setpointData['min'] or payloadValue > setpointData['max']:
             return False
         Payload = GenvexPayloadCrypt()
-        Payload.setData(GenvexCommandSetpointWriteList.buildCommand([(setpointData['write_obj'], setpointData['write_address'], newValue)]))
-        self._socket.sendto(GenvexPacket().build_packet(self._client_id, self._server_id, GenvexPacketType.DATA, 3, [Payload]), (self._device_ip, self._device_port))
-        self._last_dataupdate = time.time() - DATAPOINT_UPDATEINTERVAL + 1 # Ensure updates are check for next thread loop.
-        self._last_setpointupdate = time.time() - SETPOINT_UPDATEINTERVAL + 1
+        Payload.setData(GenvexCommandSetpointWriteList.buildCommand([(setpointData['write_obj'], setpointData['write_address'], payloadValue)]))
+        try:
+            self._socket.sendto(GenvexPacket().build_packet(self._client_id, self._server_id, GenvexPacketType.DATA, 3, [Payload]), (self._device_ip, self._device_port))
+            self._last_dataupdate = time.time() - DATAPOINT_UPDATEINTERVAL + 1 # Ensure updates are check for next thread loop.
+            self._last_setpointupdate = time.time() - SETPOINT_UPDATEINTERVAL + 1
+            self._model_adapter.notifyUpdateHandlerForKey(setpointKey, newValue) 
+            self._model_adapter._values[setpointKey] = newValue # Temporarily update the cached values to improve responsiveness. This might not be correct if the device rejects the setpoint.
+        except Exception as e:
+            _LOGGER.error(f'Error sending setpoint write request: {e}')
 
     def handleRecieve(self):
         try:
